@@ -27,8 +27,6 @@ class CustomerService:
             API response containing customer data
         """
         required_fields = [
-            "first_name",
-            "last_name",
             "type",
             "email",
             "country",
@@ -40,7 +38,13 @@ class CustomerService:
             if field not in customer_data or not customer_data[field]:
                 raise ValueError(f"{field} is required")
 
-        if customer_data["type"] == "business" and not customer_data.get("business_name"):
+        # Conditional validation based on customer type
+        if customer_data["type"] == "individual":
+            if not customer_data.get("first_name"):
+                raise ValueError("first_name is required when type is individual")
+            if not customer_data.get("last_name"):
+                raise ValueError("last_name is required when type is individual")
+        elif customer_data["type"] == "business" and not customer_data.get("business_name"):
             raise ValueError("business_name is required when type is business")
 
         return self.client.make_request("POST", "/api/external/customer", customer_data)
@@ -121,6 +125,42 @@ class CustomerService:
             "PUT", f"/api/external/customer/{customer_id}/files", file_data
         )
 
+    def list_beneficiaries(self, customer_id: str) -> Dict[str, Any]:
+        """
+        List all beneficiaries for a customer.
+
+        Args:
+            customer_id: Customer ID
+
+        Returns:
+            API response containing list of beneficiaries
+        """
+        if not customer_id:
+            raise ValueError("Customer ID is required")
+
+        return self.client.make_request("GET", f"/api/external/customer/{customer_id}/beneficiary")
+
+    def get_beneficiary(self, customer_id: str, beneficiary_id: str) -> Dict[str, Any]:
+        """
+        Get a specific beneficiary for a customer.
+
+        Args:
+            customer_id: Customer ID
+            beneficiary_id: Beneficiary ID
+
+        Returns:
+            API response containing beneficiary data
+        """
+        if not customer_id:
+            raise ValueError("Customer ID is required")
+
+        if not beneficiary_id:
+            raise ValueError("Beneficiary ID is required")
+
+        return self.client.make_request(
+            "GET", f"/api/external/customer/{customer_id}/beneficiary/{beneficiary_id}"
+        )
+
     def upload_file_complete(
         self, customer_id: str, file_options: Dict[str, Any]
     ) -> Dict[str, Any]:
@@ -169,8 +209,16 @@ class CustomerService:
                 {"customer_id": customer_id, "file_category": file_category},
             )
 
-            # Handle API response structure: {"message": "...", "file_id": "...", "url": "..."}
-            if "url" in presigned_response and "file_id" in presigned_response:
+            # Handle API response structure: {"data": {"message": "...", "file_id": "...", "url": "..."}}
+            if (
+                "data" in presigned_response
+                and "url" in presigned_response["data"]
+                and "file_id" in presigned_response["data"]
+            ):
+                # Structure: {"data": {"message": "...", "file_id": "...", "url": "..."}}
+                presigned_url = presigned_response["data"]["url"]
+                file_id = presigned_response["data"]["file_id"]
+            elif "url" in presigned_response and "file_id" in presigned_response:
                 # Direct structure from API docs
                 presigned_url = presigned_response["url"]
                 file_id = presigned_response["file_id"]
@@ -201,8 +249,19 @@ class CustomerService:
             )
 
             # Step 4: Associate file with customer
+            # Map file category to the correct field name expected by Laravel API
+            file_field_mapping = {
+                "identity": "id_file",
+                "liveness_check": "liveness_check_file",
+                "proof_of_address": "proof_of_address_file",
+            }
+
+            file_field_name = file_field_mapping.get(file_category)
+            if not file_field_name:
+                raise BlaaizError(f"Unknown file category: {file_category}")
+
             file_association = self.client.make_request(
-                "PUT", f"/api/external/customer/{customer_id}/files", {"id_file": file_id}
+                "POST", f"/api/external/customer/{customer_id}/files", {file_field_name: file_id}
             )
 
             return {
@@ -259,7 +318,7 @@ class CustomerService:
     def _download_file(self, url: str) -> Dict[str, Any]:
         """Download file from URL."""
         try:
-            req = urllib.request.Request(url, headers={"User-Agent": "Blaaiz-Python-SDK/1.0.4"})
+            req = urllib.request.Request(url, headers={"User-Agent": "Blaaiz-Python-SDK/1.1.0"})
 
             with urllib.request.urlopen(req, timeout=30) as response:
                 if response.status >= 300:
@@ -330,6 +389,12 @@ class CustomerService:
             with urllib.request.urlopen(req, timeout=30) as response:
                 if response.status < 200 or response.status >= 300:
                     raise BlaaizError(f"S3 upload failed with status {response.status}")
+
+                # Verify S3 upload success by checking for ETag
+                etag = response.headers.get("ETag")
+                if not etag:
+                    raise BlaaizError("S3 upload failed: No ETag received from S3")
+
         except urllib.error.URLError as e:
             raise BlaaizError(f"S3 upload request failed: {str(e)}")
         except Exception as e:
